function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 *  REACT COUNTDOWN COMPONENT
 *  @author  Yago Estévez.
 *  @license MIT.
 *  @version 0.0.1.
 *  @license MIT License.
 */
import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import TimeConverter from './TimeConverter';

/**
 *  REACT COUNTDOWN COMPONENT
 *  This little library provides the users with an easy to use and
 *  customizable interface, so that a countdown in hours, minutes,
 *  seconds and/or milliseconds (their choice) may be displayed in
 *  their apps with any tags, styles or any options to show it.
 * 
 *  @param {object} from (required)
 *    The actual time to start counting from. The object structure
 *    is is: { hours: #, minutes: #, seconds: #, millis: # }.
 *  @param {number} updateEvery
 *    The time interval, in milliseconds, taken into account to do
 *    the update to the onUpdate event. Default is 1000ms.
 *  @event onUpdate (required)
 *    Event required for the actual countdown to be displayed.
 *    A callback function will returns an object like this:
 *    { hours: #, minutes: #, seconds: #, millis: # }.
 */
export var CountdownContext = React.createContext();

var CountDown = function (_Component) {
  _inherits(CountDown, _Component);

  function CountDown(props) {
    _classCallCheck(this, CountDown);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.startCountdown = function () {
      _this.updateCounter();
      _this.timerRunning = true;
      _this.onStart();
    };

    _this.updateCounter = function () {
      _this.onUpdate(_this.TC.getFullTime(_this.countDown, _this.leftPadding));
      if (!_this.intervalId) {
        _this.intervalId = setInterval(function () {
          if (_this.countDown <= _this.updateInterval) return _this.onFinish();
          _this.countDown -= _this.updateInterval;
          _this.onUpdate(_this.TC.getFullTime(_this.countDown, _this.leftPadding));
        }, _this.updateInterval);
      }
    };

    _this.pauseCountdown = function () {
      _this.clearInterval();
      _this.timerRunning = false;
      _this.onPause();
    };

    _this.playPauseCountdown = function () {
      if (!_this.timerRunning) _this.startCountdown();else _this.pauseCountdown();
    };

    _this.resetCountdown = function () {
      var reset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

      _this.clearInterval();
      _this.countDown = _this.initTime;
      if (!reset) _this.onUpdate(_this.TC.getFullTime(0, _this.leftPadding));else _this.onUpdate(_this.TC.getFullTime(_this.initTime, _this.leftPadding));
      _this.timerRunning = false;
      _this.onReset();
    };

    _this.onStart = function () {
      return _this.props.onStart();
    };

    _this.onPause = function () {
      return _this.props.onPause();
    };

    _this.onReset = function () {
      return _this.props.onReset();
    };

    _this.onUpdate = function (newValue) {
      return _this.props.onUpdate(newValue);
    };

    _this.onFinish = function () {
      _this.onUpdate(_this.TC.getFullTime(0, _this.leftPadding));
      _this.resetCountdown(false);
      return _this.props.onFinish();
    };

    _this.clearInterval = function () {
      if (_this.intervalId) clearInterval(_this.intervalId);
      _this.intervalId = null;
    };

    _this.componentWillMount = function () {
      _this.onUpdate(_this.TC.getFullTime(_this.countDown, _this.leftPadding));
    };

    _this.componentWillUnmount = function () {
      _this.clearInterval();
    };

    _this.TC = new TimeConverter();
    _this.initTime = _this.TC.getMilliseconds(props.from);
    _this.countDown = _this.TC.getMilliseconds(props.from);
    _this.leftPadding = props.leftPadding || 0;
    _this.timerRunning = false;
    _this.updateInterval = props.updateEvery || 1000;
    _this.intervalId = null;
    return _this;
  }

  CountDown.prototype.render = function render() {
    return React.createElement(
      CountdownContext.Provider,
      { value: {
          start: this.startCountdown,
          pause: this.pauseCountdown,
          reset: this.resetCountdown,
          playPause: this.playPauseCountdown
        }
      },
      this.props.children
    );
  };

  return CountDown;
}(Component);

export { CountDown as default };
CountDown.propTypes = process.env.NODE_ENV !== "production" ? {
  from: PropTypes.object.isRequired,
  updateEvery: PropTypes.number,
  leftPadding: PropTypes.string,
  onStart: PropTypes.func,
  onPause: PropTypes.func,
  onReset: PropTypes.func,
  onUpdate: PropTypes.func.isRequired,
  onFinish: PropTypes.func.isRequired,
  children: PropTypes.node
} : {};